==> openGion6.2.4.0_dev.zip: uap/webapps/gf/src/org/opengion/hayabusa/html/ViewGanttTableParam.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.html;

/**
 * ガントチャート(テーブル形式)表示クラス用のパラメータ定数定義クラスです。
 *
 * パラメータのキーとなる値と、初期値を設定しています。
 * すべて、public static final で定義されている為、設定値はドキュメント等で
 * 確認することが可能です。
 * ただし、キー値などを、直書きすることを前提に公開していませんので、
 * 必要であれば、定数として、このクラス経由で使用してください。
 *
 * @og.group その他
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class ViewGanttTableParam {

	// 3.5.5.8 (2004/05/20) taglib/ViewGanttParamTag 用のキー
	/** パラメータキー {@value} */
	public static final String GROUP_COLUMNS_KEY   = "h_groupColumns"   ;
	/** パラメータキー {@value} */
	public static final String DURATION_COLUMN_KEY = "h_durationColumn" ;
	/** パラメータキー {@value} */
	public static final String DYSTART_COLUMN_KEY  = "h_dystartColumn"  ;
	/** パラメータキー {@value} */
	public static final String DYSTART_FORMAT_KEY  = "h_dystartFormat"  ;
	/** パラメータキー {@value} */
	public static final String MIN_DURATION_KEY    = "h_minDuration"    ;
	/** パラメータキー {@value} */
	public static final String HEADER_DURATION_KEY = "h_headerDuration" ;
	/** パラメータキー {@value} */
	public static final String HEADER_LOCALE_KEY   = "h_headerLocale"   ;
	/** パラメータキー {@value} */
	public static final String USE_SEQ_DAY_KEY     = "h_useSeqDay"      ;
	/** パラメータキー {@value} */
	public static final String START_DAY_KEY       = "h_startDay"       ;
	/** パラメータキー {@value} */
	public static final String END_DAY_KEY         = "h_endDay"         ;

	// 3.5.5.8 (2004/05/20) taglib/ViewGanttParamTag 用の初期値
	/** パラメータ初期値:{@value} */
	public static final String GROUP_COLUMNS_VALUE   = "PRJCODE,RESOURCE_ID"  ;
	/** パラメータ初期値:{@value} */
	public static final String DYSTART_COLUMN_VALUE  = "DYSTART"  ;
	/** パラメータ初期値:{@value} */
	public static final String DYSTART_FORMAT_VALUE  = "yyyyMMdd" ;
	/** パラメータ初期値:{@value} */
	public static final String MIN_DURATION_VALUE    = "1.0"      ;
	/** パラメータ初期値:{@value} */
	public static final String HEADER_LOCALE_VALUE   = "ja"       ;
	/** パラメータ初期値:{@value} */
	public static final String USE_SEQ_DAY_VALUE     = "false"    ;
}

==> openGion6.4.2.0_dev.zip: uap/webapps/gf/src/org/opengion/hayabusa/html/ViewGanttTableParam.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.hayabusa.html;

/**
 * ガントチャート(テーブル形式)表示クラス用のパラメータ定数定義クラスです。
 *
 * パラメータのキーとなる値と、初期値を設定しています。
 * すべて、public static final で定義されている為、設定値はドキュメント等で
 * 確認することが可能です。
 * ただし、キー値などを、直書きすることを前提に公開していませんので、
 * 必要であれば、定数として、このクラス経由で使用してください。
 *
 * @og.group その他
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public final class ViewGanttTableParam {

	/**
	 * デフォルトコンストラクター
	 * 定数クラスなので、オブジェクトを生成できないように、private にしておきます。
	 *
	 * @og.rev 6.4.2.0 (2016/01/29) PMD refactoring. Each class should declare at least one constructor.
	 */
	private ViewGanttTableParam() {
		super();		// これも、自動的に呼ばれるが、空のメソッドを作成すると警告されるので、明示的にしておきます。
	}

	// 3.5.5.8 (2004/05/20) taglib/ViewGanttParamTag 用のキー
	/** パラメータキー {@value} */
	public static final String GROUP_COLUMNS_KEY   = "h_groupColumns"   ;
	/** パラメータキー {@value} */
	public static final String DURATION_COLUMN_KEY = "h_durationColumn" ;
	/** パラメータキー {@value} */
	public static final String DYSTART_COLUMN_KEY  = "h_dystartColumn"  ;
	/** パラメータキー {@value} */
	public static final String DYSTART_FORMAT_KEY  = "h_dystartFormat"  ;
	/** パラメータキー {@value} */
	public static final String MIN_DURATION_KEY    = "h_minDuration"    ;
	/** パラメータキー {@value} */
	public static final String HEADER_DURATION_KEY = "h_headerDuration" ;
	/** パラメータキー {@value} */
	public static final String HEADER_LOCALE_KEY   = "h_headerLocale"   ;
	/** パラメータキー {@value} */
	public static final String USE_SEQ_DAY_KEY     = "h_useSeqDay"      ;
	/** パラメータキー {@value} */
	public static final String START_DAY_KEY       = "h_startDay"       ;
	/** パラメータキー {@value} */
	public static final String END_DAY_KEY         = "h_endDay"         ;

	// 3.5.5.8 (2004/05/20) taglib/ViewGanttParamTag 用の初期値
	/** パラメータ初期値:{@value} */
	public static final String GROUP_COLUMNS_VALUE   = "PRJCODE,RESOURCE_ID"  ;
	/** パラメータ初期値:{@value} */
	public static final String DYSTART_COLUMN_VALUE  = "DYSTART"  ;
	/** パラメータ初期値:{@value} */
	public static final String DYSTART_FORMAT_VALUE  = "yyyyMMdd" ;
	/** パラメータ初期値:{@value} */
	public static final String MIN_DURATION_VALUE    = "1.0"      ;
	/** パラメータ初期値:{@value} */
	public static final String HEADER_LOCALE_VALUE   = "ja"       ;
	/** パラメータ初期値:{@value} */
	public static final String USE_SEQ_DAY_VALUE     = "false"    ;
}
